"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const getConfig_1 = require("./config/getConfig");
const init_1 = require("./command/init");
const run_1 = require("./command/run");
const showHelp_1 = require("./showHelp");
const logger_1 = require("./logger");
const info_1 = require("./command/info");
const initReporters_1 = require("./logger/initReporters");
const version_1 = require("./command/version");
const cache_1 = require("./command/cache");
const worker_1 = require("./command/worker");
// Parse CLI args
const cwd = process.cwd();
try {
    const config = (0, getConfig_1.getConfig)(cwd);
    const reporters = (0, initReporters_1.initReporters)(config);
    switch (config.command[0]) {
        case "cache":
            (0, cache_1.cache)(cwd, config);
            break;
        case "init":
            (0, init_1.init)(cwd);
            break;
        case "info":
            (0, info_1.info)(cwd, config);
            break;
        case "version":
            (0, version_1.version)();
            break;
        case "experiment-worker":
            logger_1.logger.info(`Lage worker - let's make it`);
            (0, worker_1.worker)(cwd, config);
            break;
        default:
            logger_1.logger.info(`Lage task runner - let's make it`);
            (0, run_1.run)(cwd, config, reporters);
            break;
    }
}
catch (e) {
    (0, showHelp_1.showHelp)(e && e.message);
}
//# sourceMappingURL=cli.js.map